@@ -10,6 +10,7 @@
 # -------------------------------------------------------------
 
 import logging
+import time
 from hashlib import blake2b
 from ndn.app import NDNApp
 from ndn.encoding import Name, Component, FormalName
@@ -31,7 +32,6 @@ class HydraInsertClient(object):
       self.repo_prefix = repo_prefix
       self.pb = PubSub(self.app, self.client_prefix)
       self.packets = []
-      self.digests = []
 
     async def insert_file(self, file_name: FormalName, path: str) -> bool:
       """
@@ -39,7 +39,7 @@ class HydraInsertClient(object):
       """
       size, seg_cnt = 0, 0
       fetch_file_prefix = self.client_prefix + [Component.from_str("upload")] + file_name
-
+      tic = time.perf_counter()
       with open(path, "rb") as f:
         data = f.read()
         size = len(data)
@@ -50,29 +50,27 @@ class HydraInsertClient(object):
                                               final_block_id=Component.from_segment(seg_cnt - 1))
                         for i in range(seg_cnt)]
 
-        # self.digests = [bytes(blake2b(data[i*SEGMENT_SIZE:(i+1)*SEGMENT_SIZE]).digest()[:2]) for i in range(seg_cnt)]
-        # create a manifest (filled with digests) to limit signing
-
       print(f'Created {seg_cnt} chunks under name {Name.to_str(fetch_file_prefix)}')
 
       def on_interest(int_name, _int_param, _app_param):
         seg_no = Component.to_number(int_name[-1]) if Component.get_type(int_name[-1]) == Component.TYPE_SEGMENT else 0
         if seg_no < seg_cnt:
             self.app.put_raw_packet(self.packets[seg_no])
+        if seg_no == seg_cnt - 1:
+            toc = time.perf_counter()
+            print(f"The publication is complete! - total time (with disk): {toc - tic:0.4f} secs")
 
       self.app.route(fetch_file_prefix)(on_interest)
 
       file = File()
       file.file_name = file_name
       file.packets = seg_cnt
-      file.digests = self.digests
+      file.packet_size = SEGMENT_SIZE
       file.size = size
       cmd = InsertCommand()
       cmd.file = file
       cmd.fetch_path = fetch_file_prefix
       cmd_bytes = cmd.encode()
-      # what if the digests dont fit? support larger files
-      # look into implicit digests, FLICK
 
       # publish msg to repo's insert topic
       await self.pb.wait_for_ready()
